@@ -103,6 +103,13 @@ void ConfigDialog::setButtons(QDialogButtonBox::StandardButtons buttons)
         button->setAutoDefault(false);
 }
 
+void ConfigDialog::enableButton(QDialogButtonBox::StandardButton which, bool enable)
+{
+    Q_D(ConfigDialog);
+    if (QPushButton* pb = d->ui->buttons->button(which))
+        pb->setEnabled(enable);
+}
+
 void ConfigDialog::addPage(QWidget* page, const QString& name, const QString& iconName)
 {
     addPage(page, name, QStringList() << iconName);
@@ -126,7 +133,7 @@ void ConfigDialog::addPage(QWidget* page, const QString& name, const QStringList
         page->layout()->setMargin(0);
     }
 
-    QStringList icons = QStringList(iconNames) << "application-x-executable";
+    QStringList icons = QStringList(iconNames) << QL1S("application-x-executable");
     new QListWidgetItem(XdgIcon::fromTheme(icons), name, d->ui->moduleList);
     d->mIcons.append(icons);
     d->ui->stackedWidget->addWidget(page);
