@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -32,7 +32,7 @@
 #include "lxqtglobals.h"
 #include <QListWidget>
 
-namespace LxQt
+namespace LXQt
 {
 
 class LXQT_API PageSelectWidget : public QListWidget
@@ -41,10 +41,24 @@ class LXQT_API PageSelectWidget : public QListWidget
 public:
     explicit PageSelectWidget(QWidget *parent = 0);
     virtual ~PageSelectWidget();
+    int maxTextWidth() const;
+    bool event(QEvent * event) override;
+
+    int getWrappedTextWidth() const {
+        return mWrappedTextWidth;
+    }
 
 protected:
-    QSize sizeHint() const;
+    QSize viewportSizeHint() const override;
+    QSize minimumSizeHint() const override;
+
+protected slots:
+    void updateMaxTextWidth();
+
+private:
+    int mMaxTextWidth;
+    int mWrappedTextWidth;
 };
 
-} // namespace LxQt
+} // namespace LXQt
 #endif // PAGESELECTWIDGET_H
