@@ -29,6 +29,7 @@
 #include "lxqthtmldelegate.h"
 #include <QAbstractTextDocumentLayout>
 #include <QTextDocument>
+#include <QApplication>
 
 using namespace LXQt;
 
@@ -61,41 +62,49 @@ void HtmlDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option,
     doc.setHtml(options.text);
     QIcon icon = options.icon;
 
-    options.text = QString();
-    options.icon = QIcon();
-
     // icon size
     const QSize iconSize = icon.actualSize(mIconSize);
-    QRect iconRect = QRect(8, 8, iconSize.width(), iconSize.height());
+    // center the icon vertically
+    QRect iconRect = QRect(8, qMax(options.rect.height() - iconSize.height(), 0) / 2,
+                           iconSize.width(), iconSize.height());
     if (is_right_to_left)
     {
         iconRect.moveLeft(options.rect.left() + options.rect.right() - iconRect.x() - iconRect.width() + 1);
     }
 
     // set doc size
-    doc.setTextWidth(options.rect.width() - iconRect.width() - 8);
+    // NOTE: Qt has a bug, because of which HTML tags are included in QTextDocument::setTextWidth()
+    // when the text is set by QTextDocument::setHtml().
+    // As a result, the text height may be a little greater than needed.
+    doc.setTextWidth(options.rect.width() - iconRect.width() - 8 - 8); // 8-px icon-text spacing
 
-    options.widget->style()->drawControl(QStyle::CE_ItemViewItem, &options, painter);
+    // draw the item's panel
+    const QWidget* widget = option.widget;
+    QStyle* style = widget ? widget->style() : QApplication::style();
+    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &options, painter, widget);
 
     // paint icon
     painter->translate(options.rect.left(), options.rect.top());
     icon.paint(painter, iconRect);
 
+    // center the text vertically
+    painter->translate(0, qMax(static_cast<qreal>(options.rect.height()) - doc.size().height(), 0.0) / 2.0);
+
     if (!is_right_to_left)
     {
         // shift text right to make icon visible
-        painter->translate(iconRect.right() + 8, 0);
+        painter->translate((iconRect.right() + 1) + 8, 0);
     }
     const QRect clip(0, 0, options.rect.width() - iconRect.width() - 8, options.rect.height());
     painter->setClipRect(clip);
 
-    // set text color to red for selected item
+    // set text colors
     QAbstractTextDocumentLayout::PaintContext ctx;
-    if (option.state & QStyle::State_Selected)
-    {
-        QPalette::ColorGroup colorGroup = (option.state & QStyle::State_Active) ? QPalette::Active : QPalette::Inactive;
+    QPalette::ColorGroup colorGroup = (option.state & QStyle::State_Active) ? QPalette::Active : QPalette::Inactive;
+    if (option.state & QStyle::State_Selected) // selected items
         ctx.palette.setColor(QPalette::Text, option.palette.color(colorGroup, QPalette::HighlightedText));
-    }
+    else // ordinary items and those with an alternate base color (there is no alternate text color)
+        ctx.palette.setColor(QPalette::Text, option.palette.color(colorGroup, QPalette::Text));
 
     ctx.clip = clip;
     doc.documentLayout()->draw(painter, ctx);
@@ -113,15 +122,18 @@ QSize HtmlDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelInd
     initStyleOption(&options, index);
 
     const QSize iconSize = options.icon.actualSize(mIconSize);
+    // 8-px left, top and bottom margins for the icon
     const QRect iconRect = QRect(8, 8, iconSize.width(), iconSize.height());
-    const QSize optSize = options.rect.size();
+    const int w = options.rect.width();
 
     QTextDocument doc;
     doc.setHtml(options.text);
 
-    if (optSize.width() > 0)
-        doc.setTextWidth(optSize.width() - iconRect.right() - 8);
-    doc.adjustSize();
-    return QSize(0 < optSize.width() ? optSize.width() : iconRect.width() + 8 + qRound(doc.size().width())
-            , qMax(qRound(doc.size().height()), iconSize.height()) + 8);
+    if (w > 0)
+        doc.setTextWidth(static_cast<qreal>(w - (iconRect.right() + 1) - 8)); // 8-px icon-text spacing
+    else
+        doc.adjustSize();
+    return QSize(w > 0 ? w : iconRect.width() + 8 + qRound(doc.size().width()) + 8,
+                 qMax(qRound(doc.size().height() + 8), // 4-px top/bottom text spacing
+                      iconSize.height() + 16));
 }
