@@ -74,14 +74,14 @@ QLibrary* PluginInfo::loadLibrary(const QString& libDir) const
 {
     const QFileInfo fi = QFileInfo(fileName());
     const QString path = fi.canonicalPath();
-    const QString baseName = value("X-LXQt-Library", fi.completeBaseName()).toString();
+    const QString baseName = value(QL1S("X-LXQt-Library"), fi.completeBaseName()).toString();
 
-    const QString soPath = QDir(libDir).filePath(QString("lib%2.so").arg(baseName));
+    const QString soPath = QDir(libDir).filePath(QString::fromLatin1("lib%2.so").arg(baseName));
     QLibrary* library = new QLibrary(soPath);
 
     if (!library->load())
     {
-        qWarning() << QString("Can't load plugin lib \"%1\"").arg(soPath) << library->errorString();
+        qWarning() << QString::fromLatin1("Can't load plugin lib \"%1\"").arg(soPath) << library->errorString();
         delete library;
         return 0;
     }
@@ -89,7 +89,7 @@ QLibrary* PluginInfo::loadLibrary(const QString& libDir) const
     const QString locale = QLocale::system().name();
     QTranslator* translator = new QTranslator(library);
 
-    translator->load(QString("%1/%2/%2_%3.qm").arg(path, baseName, locale));
+    translator->load(QString::fromLatin1("%1/%2/%2_%3.qm").arg(path, baseName, locale));
     qApp->installTranslator(translator);
 
     return library;
@@ -140,7 +140,7 @@ PluginInfoList PluginInfo::search(const QString& desktopFilesDir, const QString&
  ************************************************/
 QDebug operator<<(QDebug dbg, const LXQt::PluginInfo &pluginInfo)
 {
-    dbg.nospace() << QString("%1").arg(pluginInfo.id());
+    dbg.nospace() << QString::fromLatin1("%1").arg(pluginInfo.id());
     return dbg.space();
 }
 
@@ -159,13 +159,13 @@ QDebug operator<<(QDebug dbg, const LXQt::PluginInfo * const pluginInfo)
  ************************************************/
 QDebug operator<<(QDebug dbg, const PluginInfoList& list)
 {
-    dbg.nospace() << '(';
+    dbg.nospace() << QL1C('(');
     for (int i=0; i<list.size(); ++i)
     {
-        if (i) dbg.nospace() << ", ";
+        if (i) dbg.nospace() << QL1S(", ");
         dbg << list.at(i);
     }
-    dbg << ')';
+    dbg << QL1C(')');
     return dbg.space();
 }
 
