@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -58,7 +58,7 @@ Power::~Power()
 
 bool Power::canAction(Power::Action action) const
 {
-    foreach(PowerProvider* provider, mProviders)
+    for(const PowerProvider* provider : qAsConst(mProviders))
     {
         if (provider->canAction(action))
             return true;
@@ -70,7 +70,7 @@ bool Power::canAction(Power::Action action) const
 
 bool Power::doAction(Power::Action action)
 {
-    foreach(PowerProvider* provider, mProviders)
+    for(PowerProvider* provider : qAsConst(mProviders))
     {
         if (provider->canAction(action) &&
             provider->doAction(action)
@@ -88,9 +88,11 @@ bool Power::canHibernate() const { return canAction(PowerHibernate); }
 bool Power::canReboot()    const { return canAction(PowerReboot);    }
 bool Power::canShutdown()  const { return canAction(PowerShutdown);  }
 bool Power::canSuspend()   const { return canAction(PowerSuspend);   }
+bool Power::canMonitorOff() const { return canAction(PowerMonitorOff);   }
 
 bool Power::logout()       { return doAction(PowerLogout);    }
 bool Power::hibernate()    { return doAction(PowerHibernate); }
 bool Power::reboot()       { return doAction(PowerReboot);    }
 bool Power::shutdown()     { return doAction(PowerShutdown);  }
 bool Power::suspend()      { return doAction(PowerSuspend);   }
+bool Power::monitorOff()   { return doAction(PowerMonitorOff);   }
