@@ -10,179 +10,187 @@
     </message>
 </context>
 <context>
-    <name>LxQt::MessageBox</name>
+    <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="70"/>
-        <source>LxQt Power Manager Error</source>
+        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <source>LXQt Power Manager Error</source>
         <translation>Fehler der LXQt-Energieverwaltung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="70"/>
+        <location filename="../lxqtpowermanager.cpp" line="74"/>
         <source>Hibernate failed.</source>
-        <translation>Tiefschlaf fehlgeschlagen.</translation>
+        <translation>Ruhezustand fehlgeschlagen.</translation>
     </message>
 </context>
 <context>
-    <name>LxQt::NotificationPrivate</name>
+    <name>LXQt::NotificationPrivate</name>
     <message>
-        <location filename="../lxqtnotification.cpp" line="152"/>
+        <location filename="../lxqtnotification.cpp" line="154"/>
         <source>Notifications Fallback</source>
         <translation>Ersatzbenachrichtigung</translation>
     </message>
 </context>
 <context>
-    <name>LxQt::PowerManager</name>
+    <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="112"/>
+        <location filename="../lxqtpowermanager.cpp" line="117"/>
         <source>Hibernate</source>
-        <translation>Tiefschlaf</translation>
+        <translation>Ruhezustand</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="119"/>
+        <location filename="../lxqtpowermanager.cpp" line="124"/>
         <source>Suspend</source>
         <translation>Bereitschaft</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="126"/>
+        <location filename="../lxqtpowermanager.cpp" line="131"/>
         <source>Reboot</source>
         <translation>Neustart</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="133"/>
+        <location filename="../lxqtpowermanager.cpp" line="138"/>
         <source>Shutdown</source>
         <translation>Herunterfahren</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="140"/>
+        <location filename="../lxqtpowermanager.cpp" line="145"/>
         <source>Logout</source>
         <translation>Abmelden</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="152"/>
-        <source>LxQt Session Suspend</source>
-        <translation>LXQt Bereitschaft</translation>
+        <location filename="../lxqtpowermanager.cpp" line="157"/>
+        <source>LXQt Session Suspend</source>
+        <translation>Bereitschaft der LXQT-Sitzung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="153"/>
+        <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
-        <translation>Möchten Sie ihren Computer in Bereitschaft versetzen?&lt;p&gt;Dies versetzt ihren Computer in einen Energiesparmodus. Der Systemzustand geht verloren, wenn die Energiezufuhr abbricht.</translation>
+        <translation>Möchten Sie ihren Computer in Bereitschaft versetzen?&lt;p&gt;Der Computer wird in einen Energiesparmodus versetzt. Der Systemzustand geht verloren, wenn die Energiezufuhr abbricht.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="162"/>
-        <source>LxQt Session Hibernate</source>
-        <translation>LXQt Tiefschlaf</translation>
+        <location filename="../lxqtpowermanager.cpp" line="167"/>
+        <source>LXQt Session Hibernate</source>
+        <translation>Ruhezustand der LXQT-Sitzung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="163"/>
+        <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
-        <translation>Möchten Sie ihren Computer in Tiefschlaf versetzen?&lt;p&gt;Dies versetzt ihren Computer in einen Energiesparmodus. Der Systemzustand bleibt erhalten, wenn die Energiezufuhr abbricht.</translation>
+        <translation>Möchten Sie ihren Computer in Ruhezustand versetzen?&lt;p&gt;Dies versetzt ihren Computer in einen Energiesparmodus. Der Systemzustand bleibt erhalten, wenn die Energiezufuhr abbricht.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="172"/>
-        <source>LxQt Session Reboot</source>
-        <translation>LXQt Neustart</translation>
+        <location filename="../lxqtpowermanager.cpp" line="177"/>
+        <source>LXQt Session Reboot</source>
+        <translation>Neustart der LXQT-Sitzung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="173"/>
+        <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
         <translation>Möchten Sie ihren Computer wirklich neustarten? Alle ungespeicherten Arbeiten gehen verloren...</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="182"/>
-        <source>LxQt Session Shutdown</source>
-        <translation>LXQt Herunterfahren</translation>
+        <location filename="../lxqtpowermanager.cpp" line="187"/>
+        <source>LXQt Session Shutdown</source>
+        <translation>Herunterfahren der LXQT-Sitzung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="183"/>
+        <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation>Möchten Sie ihren Computer wirklich herunterfahren? Alle ungespeicherten Arbeiten gehen verloren...</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="192"/>
-        <source>LxQt Session Logout</source>
-        <translation>LXQt Abmelden</translation>
+        <location filename="../lxqtpowermanager.cpp" line="197"/>
+        <source>LXQt Session Logout</source>
+        <translation>Abmelden der LXQT-Sitzung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="193"/>
+        <location filename="../lxqtpowermanager.cpp" line="198"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation>Möchten Sie sich wirklich abmelden? Alle ungespeicherten Arbeiten gehen verloren...</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="201"/>
         <location filename="../lxqtpowermanager.cpp" line="206"/>
-        <source>LxQt Power Manager Error</source>
+        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <source>LXQt Power Manager Error</source>
         <translation>Fehler der LXQt-Energieverwaltung</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="201"/>
+        <location filename="../lxqtpowermanager.cpp" line="206"/>
         <source>Hibernate failed.</source>
-        <translation>Tiefschlaf fehlgeschlagen.</translation>
+        <translation>Ruhezustand fehlgeschlagen.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../lxqtpowermanager.cpp" line="211"/>
         <source>Suspend failed.</source>
         <translation>Bereitschaft fehlgeschlagen.</translation>
     </message>
 </context>
 <context>
-    <name>LxQt::ScreenSaver</name>
+    <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="51"/>
+        <location filename="../lxqtscreensaver.cpp" line="236"/>
         <source>Lock Screen</source>
         <translation>Bildschirm sperren</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="76"/>
+        <location filename="../lxqtscreensaver.cpp" line="156"/>
         <source>Screen Saver Error</source>
         <translation>Bildschirmschoner-Fehler</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="77"/>
+        <location filename="../lxqtscreensaver.cpp" line="157"/>
         <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
         <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Syntaxfehler in den Parametern für xdg-screensaver.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="84"/>
-        <location filename="../lxqtscreensaver.cpp" line="92"/>
-        <location filename="../lxqtscreensaver.cpp" line="101"/>
+        <location filename="../lxqtscreensaver.cpp" line="162"/>
+        <location filename="../lxqtscreensaver.cpp" line="168"/>
+        <location filename="../lxqtscreensaver.cpp" line="175"/>
         <source>Screen Saver Activation Error</source>
         <translation>Fehler beim Aktivieren des Bildschirmschoners</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="85"/>
+        <location filename="../lxqtscreensaver.cpp" line="163"/>
         <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
         <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Bitte stellen Sie sicher, dass xscreensaver installiert ist und funktioniert.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="93"/>
+        <location filename="../lxqtscreensaver.cpp" line="169"/>
         <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
         <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Aktion &apos;aktivieren&apos; fehlgeschlagen. Bitte stellen Sie sicher, dass xscreensaver installiert ist und funktioniert.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="102"/>
+        <location filename="../lxqtscreensaver.cpp" line="176"/>
         <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
         <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Unbekannter Fehler - ein undokumentierter Rückgabewert wurde von xdg-screensaver ausgegeben: %1.</translation>
     </message>
 </context>
+<context>
+    <name>QCoreApplication</name>
+    <message>
+        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
+        <source>Choose the page to be shown.</source>
+        <translation>Wähle die darzustellende Seite.</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
         <source>Power Manager Error</source>
-        <translation>Fehler der Energieverwaltung</translation>
+        <translation>Energieverwaltungsfehler</translation>
     </message>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
         <translation>QDBusInterface ist ungültig</translation>
     </message>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
-        <translation>Fehler der Energieverwaltung (D-BUS-Aufruf)</translation>
+        <translation>Energieverwaltungsfehler (D-BUS-Aufruf)</translation>
     </message>
 </context>
 </TS>
